==> aliyun-python-sdk-cdrs-1.0.3.tar.gz: aliyun-python-sdk-cdrs-1.0.3/aliyunsdkcdrs/request/v20201101/BindDeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class BindDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CDRS', '2020-11-01', 'BindDevice')
		self.set_method('POST')

	def get_CorpId(self):
		return self.get_body_params().get('CorpId')

	def set_CorpId(self,CorpId):
		self.add_body_params('CorpId', CorpId)

	def get_Devicess(self):
		return self.get_body_params().get('Devices')

	def set_Devicess(self, Devicess):
		for depth1 in range(len(Devicess)):
			if Devicess[depth1].get('CorpId') is not None:
				self.add_body_params('Devices.' + str(depth1 + 1) + '.CorpId', Devicess[depth1].get('CorpId'))
			if Devicess[depth1].get('DeviceId') is not None:
				self.add_body_params('Devices.' + str(depth1 + 1) + '.DeviceId', Devicess[depth1].get('DeviceId'))

==> aliyun-python-sdk-cdrs-1.0.6.tar.gz: aliyun-python-sdk-cdrs-1.0.6/aliyunsdkcdrs/request/v20201101/BindDeviceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class BindDeviceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CDRS', '2020-11-01', 'BindDevice')
		self.set_method('POST')

	def get_CorpId(self):
		return self.get_body_params().get('CorpId')

	def set_CorpId(self,CorpId):
		self.add_body_params('CorpId', CorpId)

	def get_Devices(self):
		return self.get_body_params().get('Devices')

	def set_Devices(self, Devicess):
		for depth1 in range(len(Devicess)):
			if Devicess[depth1].get('CorpId') is not None:
				self.add_body_params('Devices.' + str(depth1 + 1) + '.CorpId', Devicess[depth1].get('CorpId'))
			if Devicess[depth1].get('DeviceId') is not None:
				self.add_body_params('Devices.' + str(depth1 + 1) + '.DeviceId', Devicess[depth1].get('DeviceId'))
